@@ -10,7 +10,7 @@ class YamlConfig():
     def load(self,filename):
         f = open(filename, 'r', encoding='utf-8')
         cont = f.read()
-        x = yaml.load(cont)
+        x = yaml.load(cont, Loader=yaml.FullLoader)
         return x
         # print(type(x))
         # print(x)
